stickNAUTA
==========

This is a simple managing interface for ETECSA Nauta with the minimal requirements.

DONE
----
  + Session account status, credit and last three connections.
  + Session login.
  + Session remaining time.
  + Session logout.
  + Session is context friendly.
  + Session data can be saved/load to/from memory or file to save/recover the session.

TODO
----
  - Portal account information.
  - Portal account password change.
  - Portal account recharge.
